==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationHighTrafficArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationHighTrafficArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationHighTrafficArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationHighTrafficArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("oqyhpyijxbrxtrob")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("jspjnvhcwoeievhj")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("doottjwvrgrqhqvf")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qdixndnvnmbktigx")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("wnicagpeqxwxiqwn")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("imrpwytmfextoogf")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("cwtubnmuygretwia")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationHighTrafficArgs =
        DefaultRolloutSpecificationHighTrafficArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/DefaultRolloutSpecificationHighTrafficArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property regions
 * @property waitDuration
 */
public data class DefaultRolloutSpecificationHighTrafficArgs(
    public val regions: Output<List<String>>? = null,
    public val waitDuration: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs =
        com.pulumi.azurenative.providerhub.inputs.DefaultRolloutSpecificationHighTrafficArgs.builder()
            .regions(regions?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .waitDuration(waitDuration?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DefaultRolloutSpecificationHighTrafficArgs].
 */
@PulumiTagMarker
public class DefaultRolloutSpecificationHighTrafficArgsBuilder internal constructor() {
    private var regions: Output<List<String>>? = null

    private var waitDuration: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("irirrayhtywucxms")
    public suspend fun regions(`value`: Output<List<String>>) {
        this.regions = value
    }

    @JvmName("jeyiurcnxhqmjnxe")
    public suspend fun regions(vararg values: Output<String>) {
        this.regions = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("hgxfxydimeuhdfnc")
    public suspend fun regions(values: List<Output<String>>) {
        this.regions = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("nnvyryxhubaxnibr")
    public suspend fun waitDuration(`value`: Output<String>) {
        this.waitDuration = value
    }

    /**
     * @param value
     */
    @JvmName("uewpphfrrqymdkkw")
    public suspend fun regions(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param values
     */
    @JvmName("jjluutsbxtcuyxrq")
    public suspend fun regions(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regions = mapped
    }

    /**
     * @param value
     */
    @JvmName("ftriayjjfrtmcemt")
    public suspend fun waitDuration(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.waitDuration = mapped
    }

    internal fun build(): DefaultRolloutSpecificationHighTrafficArgs =
        DefaultRolloutSpecificationHighTrafficArgs(
            regions = regions,
            waitDuration = waitDuration,
        )
}
